@@ -1,5 +1,5 @@
 from enum import Enum
  
 class FileExists(Enum):
-    FILEEXIST = 1
-    FILENOTEXIST = 2
+    FILE_EXIST = 1
+    FILE_NOT_EXIST = 2
